pub fn detect_needed_dependencies(directory: &Path) -> Result<DependencyNeeds>Expand description
Smart detection: scan directory and determine which dependencies are actually needed
pub fn detect_needed_dependencies(directory: &Path) -> Result<DependencyNeeds>Smart detection: scan directory and determine which dependencies are actually needed