pub struct RenameHistory { /* private fields */ }Expand description
Rename history tracker
Implementations
Sourceimpl RenameHistory
impl RenameHistory
Sourcepub fn load(history_path: PathBuf, max_history: usize) -> Result<Self>
pub fn load(history_path: PathBuf, max_history: usize) -> Result<Self>
Load history from disk, or create new if doesn’t exist
Sourcepub fn add(&mut self, operation: RenameOperation)
pub fn add(&mut self, operation: RenameOperation)
Add a rename operation to the history
Sourcepub fn operations(&self) -> &VecDeque<RenameOperation>
pub fn operations(&self) -> &VecDeque<RenameOperation>
Get all operations (newest first)
Sourcepub fn last_undoable(&self) -> Option<&RenameOperation>
pub fn last_undoable(&self) -> Option<&RenameOperation>
Get the most recent operation that can be undone
Sourcepub fn undoable_count(&self) -> usize
pub fn undoable_count(&self) -> usize
Get count of undoable operations